@@ -31,6 +31,8 @@
 
 #include <string>
 #include <map>
+#include <vector>
+#include <bitset>
 
 namespace libvoikko { namespace morphology {
 
@@ -41,6 +43,30 @@ namespace libvoikko { namespace morphology {
  */
 class Analysis {
 	public:
+		enum class Key {
+			BASEFORM,
+			CLASS,
+			COMPARISON,
+			FOCUS,
+			FSTOUTPUT,
+			KYSYMYSLIITE,
+			MALAGA_VAPAA_JALKIOSA,
+			MOOD,
+			NEGATIVE,
+			NUMBER,
+			PARTICIPLE,
+			PERSON,
+			POSSESSIVE,
+			POSSIBLE_GEOGRAPHICAL_NAME,
+			REQUIRE_FOLLOWING_VERB,
+			SIJAMUOTO,
+			STRUCTURE,
+			TENSE,
+			WEIGHT,
+			WORDBASES,
+			WORDIDS
+		};
+		
 		Analysis();
 		~Analysis();
 		
@@ -48,32 +74,54 @@ class Analysis {
 		 * Adds an attribute to analysis. Ownership of value
 		 * is transferred to this object.
 		 */
-		void addAttribute(const char * key, wchar_t * value);
+		void addAttribute(Key key, wchar_t * value);
+		
+		/**
+		 * Adds an attribute to analysis without transferring ownership.
+		 */
+		void addConstAttribute(Key key, const wchar_t * value);
 		
 		/**
 		 * Deletes an attribute from analysis.
 		 */
-		void removeAttribute(const char * key);
+		void removeAttribute(Key key);
+		
+		/**
+		 * Seals this analysis for publication through external interface
+		 */
+		void seal();
 		
 		/**
 		 * Returns a null terminated array of strings containing
 		 * the attribute names in this analysis.
 		 */
 		const char ** getKeys() const;
+		
+		/**
+		 * Returns a list of attribute keys in this analysis.
+		 */
+		std::vector<Key> getInternalKeys() const;
 
 		/**
 		 * Returns the value of given attribute. If no such
 		 * attribute exists, returns null.
 		 */
-		const wchar_t * getValue(const char * key) const;
+		const wchar_t * getValue(Key key) const;
+		
+		/**
+		 * Returns the value of given attribute. If no such
+		 * attribute exists, returns null.
+		 */
+		const wchar_t * getValueS(const char * key) const;
+		
 	private:
 		Analysis(Analysis const & other);
 		Analysis & operator = (const Analysis & other);
 		
 		void deleteKeys();
-		void recreateKeys();
 		const char ** keys;
-		std::map<std::string, wchar_t *> attributes;
+		std::map<Key, wchar_t *> attributes;
+		std::bitset<21> constAttributes;
 };
 
 } }
