@@ -42,14 +42,14 @@ namespace libvoikko { namespace morphology {
  */
 class HfstAnalyzer : public Analyzer {
 	public:
-		HfstAnalyzer(const std::string & directoryName);
+		explicit HfstAnalyzer(const std::string & directoryName);
 		std::list<Analysis *> * analyze(const wchar_t * word, size_t wlen, bool fullMorphology);
 		std::list<Analysis *> * analyze(const char * word, bool fullMorphology);
 		void terminate();
 
 		HfstAnalyzer & operator = (const HfstAnalyzer & other);
 	private:
-		hfst_ol::Transducer *t;
+		hfst_ospell::Transducer *t;
 
 		HfstAnalyzer(HfstAnalyzer const & other);
 
