@@ -44,12 +44,12 @@ namespace libvoikko { namespace spellchecker {
 class HfstSpeller : public Speller {
 	public:
 		/** Constructor for V3 stable format */
-		HfstSpeller(const std::string & zhfstFileName, voikko_options_t * voikkoOptions) throw(setup::DictionaryException);
+		HfstSpeller(const std::string & zhfstFileName, voikko_options_t * voikkoOptions);
 		spellresult spell(const wchar_t * word, size_t wlen);
 		void terminate();
 		
 		/** Public for use in HfstSuggestion */
-		hfst_ol::ZHfstOspeller * speller;
+		hfst_ospell::ZHfstOspeller * speller;
 	private:
 		/** Return SPELL_FAILED or SPELL_OK depending on whether given word is correct as is. */
 		spellresult doSpell(const wchar_t * word, size_t wlen);
